/*
This is a list of all code used to generate the results in the paper. Running
this file will run all the code in sequence. This might take some time, due to
the computationally intensive implementation of the wild bootstrap we relied on.
*/

do setup //Sets up some global variables


*****************
*** Data Prep ***
*****************

do "$code/getIncData"  //Constructs day-tehsil-level data from geo-coded BFRS 
					   //data and adds additional covariates.

do "$code/monthlyData" //Compiles day-tehsil-level data into month-tehsil-level
					   //data.


******************************************
*** DiD, Event Study and Decomposition ***
******************************************

do "$code/diffInDiff" //Executes main DiD regresions presented in Table 2 and 
					  //Table 3 as well as Figure 6. Due to bootstrapping, the 
					  //code may take a long time to run.
					  
do "$code/eventStudy" //Executes event-study regressions and generates graphs
					  //presented in Figure 7 of the main text. Also executes 
					  //the event-study regressions presented in Figure 1 and
					  //Figure 2 of the supplement.
					  
do "$code/decomp"	  //Executes decomposition regressions presented in 
					  //Table 4. Due to bootstrapping, the code may take a 
					  //long time to run.


**********************************
*** Summary Tables and Figures ***
**********************************

do "$code/balance"	  	//Generates summary statistics presented in Table 1.

do "$code/summary"	  	//Generates Figure 5, presenting measures of 
						//monthly violence by district.

do "$code/strikeGraphs"	//Generates Figure 2, showing montly drone strikes
						//in North Wazirstan.

do "$code/parallel"	  	//Generates Figure 3, depicting trends in violence
						//inside and outside of drone program region before
						//and after program commencement.


***************************
*** Supplemental Reslts ***
***************************

do "$code/placebo"		//Runs regressions for placebo tests presented in
						//Figures 3-10 of the supplement.

do "$code/summaryPIPS"	//Generates Figures 11 and 12 of the supplement,
						//presenting monthly violence measures by district, 
						//based on PIPS violence data.

